@@ -1,12 +1,10 @@
 import pytest
 
-from bstb.core import Waypoint, Latitude, Longitude
+from bstb.core import Waypoint
 
 
 def test_constructor_01():
-    lat = Latitude()
-    lng = Longitude()
-    wp = Waypoint(lat, lng)
+    wp = Waypoint()
 
     assert wp
     assert wp.latitude
